..
    This file is part of Invenio.
    Copyright (C) 2017-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _maintainer-guide:

Maintainer's guide
==================

Following is a guide for *maintainers* and *architects* who are the responsible
for maintaining one or more repositories.

.. toctree::
   :maxdepth: 2

   overview
   repositories
   releasing
   copyright-policy


.. todo: branches, reviewing, merging, releasing, deprecating, faq
